OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Вбудоване повідомлення %s",
    "Important mail" : "Важлива пошта",
    "No message found yet" : "Відсутні повідомлення",
    "Set up an account" : "Створити обліковий запис",
    "Unread mail" : "Непрочитана пошта",
    "Important" : "Важливі",
    "Work" : "Робочий",
    "Personal" : "Особисте",
    "To Do" : "Зробити",
    "Later" : "Пізніше",
    "Mail" : "Пошта",
    "You are reaching your mailbox quota limit for {account_email}" : "Ви майже вичерпали доступний вам обсяг поштової скриньки {account_email}",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Поточний обсяг вагої поштової скриньки {percentage}. Ви можете звільнити більше місця, якщо вилучите непотрібні електронні листи.",
    "Mails" : "Пошта",
    "💌 A mail app for Nextcloud" : "💌 Поштовий застосунок для Nextcloud",
    "Your session has expired. The page will be reloaded." : "Ваш сеанс закінчився. Сторінка буде перезавантажена.",
    "Drafts are saved in:" : "Чернетки зберігаються в:",
    "Sent messages are saved in:" : "Надіслані повідомлення зберігаються в:",
    "Deleted messages are moved in:" : "Вилучені листи буде переміщено до:",
    "Archived messages are moved in:" : "Архівні повідомлення перенесено:",
    "Snoozed messages are moved in:" : "Відкладені повідомлення буде переміщено до:",
    "Junk messages are saved in:" : "Спам зберігатиметься у:",
    "Connecting" : "Підключення",
    "Reconnect Google account" : "Повторно підключіть обліковий запис Google",
    "Sign in with Google" : "Увійдіть за допомогою Google",
    "Save" : "Зберегти",
    "Connect" : "З'єднати",
    "Looking up configuration" : "Пошук конфігурації",
    "Checking mail host connectivity" : "Перевірка підключення до поштового хосту",
    "Configuration discovery failed. Please use the manual settings" : "Помилка виявлення конфігурації. Будь ласка, використовуйте ручні налаштування",
    "Password required" : "Зазначте пароль",
    "Testing authentication" : "Перевірка авторизації",
    "Awaiting user consent" : "Очікуємо на згоду користувача",
    "Account created. Please follow the pop-up instructions to link your Google account" : "Обліковий запис створено. Дотримуйтеся інструкцій, що з'являтимуться, щоби під'єднати вашу скриньку Google",
    "Loading account" : "Завантажуємо обліковий запис",
    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Обліковий запис оновлено. Дотримуйтеся інструкцій, що з'являтимуться, для повторного під'єднання вашої скриньки Google.",
    "Account updated" : "Обліковий запис оновлено",
    "IMAP server is not reachable" : "Сервер IMAP недоступний",
    "SMTP server is not reachable" : "Сервер SMTP недоступний",
    "IMAP username or password is wrong" : "Ім'я користувача або пароль IMAP неправильні",
    "SMTP username or password is wrong" : "Ім'я користувача або пароль SMTP неправильні",
    "IMAP connection failed" : "Помилка підключення IMAP",
    "SMTP connection failed" : "Помилка підключення SMTP",
    "Authorization pop-up closed" : "Вікно авторизації закрито",
    "Configuration discovery temporarily not available. Please try again later." : "Виявлення налаштувань тимчасово недоступне. Спробуйте пізніше.",
    "There was an error while setting up your account" : "Під час налаштування облікового запису сталася помилка",
    "Auto" : "Автоматично",
    "Name" : "Ім'я",
    "Mail address" : "Поштова адреса",
    "name@example.org" : "name@example.org",
    "Please enter an email of the format name@example.com" : "Введіть адресу електронної пошти у форматі name@example.com",
    "Password" : "Пароль",
    "Manual" : "Вручну",
    "IMAP Settings" : "Налаштування IMAP",
    "IMAP Host" : "Вузол IMAP",
    "IMAP Security" : "Безпека IMAP",
    "None" : "Відсутній",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Порт IMAP",
    "IMAP User" : "Користувач IMAP",
    "IMAP Password" : "Пароль IMAP",
    "SMTP Settings" : "Налаштування SMTP",
    "SMTP Host" : "Вузол SMTP",
    "SMTP Security" : "Безпека SMTP",
    "SMTP Port" : "Порт SMTP",
    "SMTP User" : "Користувач SMTP",
    "SMTP Password" : "Пароль SMTP",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Щоби мати доступ до цього застосунку з обліковим записом Google, вам потрібно увімкнути двофакторну авторизації у вашому обліковому записі Google, налаштувати пароль для застосунка.",
    "Account settings" : "Налаштування облікового запису",
    "Aliases" : "Синоніми",
    "Alias to S/MIME certificate mapping" : "Синонім для мапування сертифікату S/MIME",
    "Signature" : "Підпис",
    "A signature is added to the text of new messages and replies." : "Додавати підпис до тексту нових повідомлень та відповідей.",
    "Writing mode" : "Режим редагування",
    "Preferred writing mode for new messages and replies." : "Режим редагування нових повідомлень та відповідей, якому ви віддаєте перевагу.",
    "Default folders" : "Типові каталоги",
    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "Каталоги для чернеток, надісланих, вилучених, заархівованих листів та листів, що позначено яко спам.",
    "Automatic trash deletion" : "Автоматичне спорожнення кошику",
    "Days after which messages in Trash will automatically be deleted:" : "Кількість днів, після спливання яких, листи у кошику буде автоматично вилучено:",
    "Autoresponder" : "Автовідповідач",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Автоматична відповідь на вхідні повідомлення. Якщо хтось надсилає вам кілька повідомлень, ця автоматична відповідь надсилатиметься щонайбільше раз на 4 дні.",
    "Filters" : "Фільтри",
    "Mail server" : "Поштовий сервер",
    "Mailbox search" : "Пошук поштової скриньки",
    "Update alias" : "Оновити синонім",
    "Rename alias" : "Перейменувати синонім",
    "Show update alias form" : "Показати форму оновлення синоніму",
    "Delete alias" : "Вилучити синонім",
    "Go back" : "Повернутися назад",
    "Change name" : "Змінити ім'я",
    "Email address" : "Адреса ел.пошти",
    "Add alias" : "Додати синонім",
    "Create alias" : "Створити синонім",
    "Cancel" : "Скасувати",
    "Search in the body of messages in priority Inbox" : "Шукати в тілі листів у пріоритетних вхідних",
    "Activate" : "Увімкнути",
    "Put my text to the bottom of a reply instead of on top of it." : "Розташовувати мій текст під відповіддю, а не над нею.",
    "Could not update preference" : "Не вдалося оновити уподобання",
    "Mail settings" : "Налаштування пошти",
    "Accounts" : "Облікові записи",
    "Add mail account" : "Додати обліковий запис",
    "General" : "Загальна",
    "Layout" : "Подання",
    "List" : "Список",
    "Vertical split" : "Розділено по вертикалі",
    "Horizontal split" : "Розділено по горизонталі",
    "Sorting" : "Впорядкування",
    "Newest" : "Найновіший",
    "Oldest" : "Найстарший",
    "Reply text position" : "Місце розташування відповіді",
    "Gravatar settings" : "Налаштування Gravatar",
    "Use Gravatar and favicon avatars" : "Використовувати Gravatar та вподобані значки",
    "Register as application for mail links" : "Зробити типовим застосунком ел.пошти",
    "Register" : "Зареєструватися",
    "Data collection consent" : "Погодження на збір даних",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Дозволити застосунку збирати дані про вашу взаємодію. На основі цих даних застосунок буде підлаштовувати видачу. Дані зберігатимуться виключно локально.",
    "Trusted senders" : "Довірені адресати",
    "Manage S/MIME certificates" : "Керування сертифікатами S/MIME",
    "Looking for a way to encrypt your emails?" : "Шукаєте спосіб зашифрувати свою електронну пошту?",
    "Install Mailvelope browser extension by clicking here" : "Щоби встановити розширення Mailvelope для бравзера, клацніть тут",
    "About" : "Про сервіс",
    "Keyboard shortcuts" : "Скорочення",
    "Compose new message" : "Нове повідомлення",
    "Newer message" : "Новіші повідомлення",
    "Older message" : "Старіші повідомлення",
    "Toggle star" : "Перемкнути зірочку",
    "Toggle unread" : "Перемкнути непрочитане",
    "Archive" : "Архів",
    "Delete" : "Вилучити",
    "Search" : "Пошук",
    "Send" : "Надіслати",
    "Refresh" : "Оновити",
    "No certificate" : "Немає сертифіката",
    "Certificate updated" : "Сертифікат оновлено",
    "Could not update certificate" : "Не вдалося оновити сертифікат",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - дійсно до {expiryDate}",
    "Select an alias" : "Виберіть синонім",
    "Select certificates" : "Виберіть сертифікати",
    "Update Certificate" : "Оновити сертифікат",
    "Encrypt with S/MIME and send later" : "Зашифрувати за допомогою S/MIME та надіслати пізніше",
    "Encrypt with S/MIME and send" : "Зашифрувати за допомогою S/MIME та надіслати",
    "Encrypt with Mailvelope and send later" : "Зашифрувати за допомогою Mailvelope та надіслати пізніше",
    "Encrypt with Mailvelope and send" : "Зашифрувати за допомогою Mailvelope та надіслати",
    "Send later" : "Надішліть пізніше",
    "Message {id} could not be found" : "Неможливо знайти лист {id}",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Вибрано додавання підпису або шифрування за допомогою S/MIME, проте відсутній сертифікат для вибраного синоніму. Лист не буде підписано аба зашифровано.",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Будь-яке існуюче форматування (наприклад, напівгрубий шрифт, курсив, підкреслені чи вбудовані зображення) буде видалено.",
    "Turn off formatting" : "Вимкніть форматування",
    "Turn off and remove formatting" : "Вимкніть та приберіть форматування",
    "Keep formatting" : "Продовжуйте форматувати",
    "From" : "Від",
    "Select account" : "Оберіть обліковий запис",
    "To" : "Кому",
    "Select recipient" : "Виберіть отримувача",
    "Contact or email address …" : "Контакт або ел.адреса...",
    "Cc" : "Копія",
    "Bcc" : "Всс",
    "Subject" : "Тема",
    "Subject …" : "Тема...",
    "This message came from a noreply address so your reply will probably not be read." : "Це повідомлення надійшло з адреси, яка не приймає відповідей, таким чином вашу відповідь можуть не прочитати.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "Ці отримувачі не мають сертифікату S/MIME: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : "Ці отримувачі не мають ключа PGP: {recipients}.",
    "Write message …" : "Написати повідомлення...",
    "Saving draft …" : "Збереження чернетки ...",
    "Error saving draft" : "Помилка під час збереження чернетки",
    "Draft saved" : "Чернетку збережено",
    "Save draft" : "Зберегти чернетку",
    "Discard & close draft" : "Відхилити та закрити чернетку",
    "Enable formatting" : "Увімкнути форматування",
    "Disable formatting" : "Вимкнути форматування",
    "Upload attachment" : "Завантажити вкладення",
    "Add attachment from Files" : "Додати вкладення з Файлів",
    "Smart picker" : "Асистент розумного вибору",
    "Request a read receipt" : "Запитати підтвердження про прочитання",
    "Sign message with S/MIME" : "Підписати лист за допомогою S/MIME",
    "Encrypt message with S/MIME" : "Шифрувати лист за допомогою S/MIME",
    "Encrypt message with Mailvelope" : "Шифрувати лист за допомогою Mailvelope",
    "Send now" : "Надіслати зараз",
    "Tomorrow morning" : "Завтра вранці",
    "Tomorrow afternoon" : "Завтра вдень",
    "Monday morning" : "У понеділок вранці",
    "Custom date and time" : "Власна дата та час",
    "Enter a date" : "Введіть дату",
    "Choose" : "Вибрати",
    "Choose a file to add as attachment" : "Виберіть файл для вкладення",
    "Choose a file to share as a link" : "Виберіть файл, яким ви поділитеся через посилання",
    "_{count} attachment_::_{count} attachments_" : ["{count} долучений файл","{count} долучені файли","{count} долучених файлів","{count} долучених файлів"],
    "Untitled message" : "Лист без назви",
    "Expand composer" : "Розгорнути редактор",
    "Close composer" : "Закрити редактор",
    "Confirm" : "Підтвердити",
    "Tag: {name} deleted" : "Мітка: {name} вилучено",
    "An error occurred, unable to delete the tag." : "Пимилка під час вилучення мітки.",
    "The tag will be deleted from all messages." : "Мітку буде вилучено зі всіх листів.",
    "Plain text" : "Простий текст",
    "Rich text" : "Текст з форматуванням",
    "No messages in this mailbox" : "Відсутні листи у поштовій скриньці",
    "No messages" : "Відсутні повідомлення",
    "Blind copy recipients only" : "Лише отримувачі у прихованій копії",
    "No subject" : "Без теми",
    "Set reminder for later today" : "Встановити нагадування на сьогодні пізніше",
    "Set reminder for tomorrow" : "Встановити нагадування на завтра",
    "This weekend – {timeLocale}" : "На цих вихідних - {timeLocale}",
    "Set reminder for this weekend" : "Встановити нагадування на ці вихідні",
    "Next week – {timeLocale}" : "Наступного тижня - {timeLocale}",
    "Set reminder for next week" : "Встановити нагадування на наступний тиждень",
    "No trash mailbox configured" : "Кошик для листів не налаштовано",
    "Could not delete message" : "Не вдалося вилучити лист",
    "Could not archive message" : "Не вдалося архівувати лист",
    "Thread was snoozed" : "Ланцюг відкладено",
    "Could not snooze thread" : "Не вдалося відкласти ланцюг",
    "Thread was unsnoozed" : "Ланцюг знову актуалізовано",
    "Could not unsnooze thread" : "Не вдалося актуалізуати ланцюг",
    "Draft: " : "Чернетка:",
    "Encrypted message" : "Лист із шифруванням",
    "This message is unread" : "Це повідомлення не прочитано",
    "Unfavorite" : "Прибрати зірочку",
    "Favorite" : "Із зірочкою",
    "Unread" : "Непрочитане",
    "Read" : "Читати",
    "Unimportant" : "Неважливе",
    "Mark not spam" : "Позначити як не спам",
    "Mark as spam" : "Позначити як спам",
    "Edit tags" : "Редагувати мітки",
    "Snooze" : "Відкласти",
    "Unsnooze" : "Актуальне",
    "Move thread" : "Пересунути ланцюг",
    "Archive thread" : "Архівувати ланцюг",
    "Archive message" : "Архівувати повідомлення",
    "Delete thread" : "Вилучити ланцюг",
    "Delete message" : "Вилучити повідомлення",
    "More actions" : "Більше дій",
    "Back" : "Назад",
    "Set custom snooze" : "Налаштувати, на скільки відкладати",
    "Edit as new message" : "Редагувати як нове повідомлення",
    "Create event" : "Додати подію",
    "Create task" : "Створити завдання",
    "Download message" : "Звантажити повідомлення",
    "Load more" : "Більше",
    "_Mark {number} read_::_Mark {number} read_" : ["Позначити {number} прочитаним","Позначити {number} прочитаними","Позначити {number} прочитаними","Позначити {number} прочитаними"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Позначити {number} непрочитаним","Позначити {number} непрочитаними","Позначити {number} непрочитаними","Позначити {number} непрочитаними"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Позначити {number} важливим","Позначити {number} важливими","Позначити {number} важливими","Позначити {number} важливими"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Позначити {number} неважливим","Позначити {number} неважливими","Позначити {number} неважливими","Позначити {number} неважливими"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Без зірки {number}","Без зірки {number}","Без зірки {number}","Без зірочки {number}"],
    "_Favorite {number}_::_Favorite {number}_" : ["Із зіркою {number}","Із зіркою {number}","Із зіркою {number}","Із зірочкою {number}"],
    "_Unselect {number}_::_Unselect {number}_" : ["Не вибрано {number}","Не вибрано {number}","Не вибрано {number}","Не вибрано {number}"],
    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Позначити {number} спамом","Позначити {number} спамом","Позначити {number} спамом","Позначити {number} спамом"],
    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["Позначити {number} не спамом","Позначити {number} не спамом","Позначити {number} не спамом","Позначити {number} не спамом"],
    "_Edit tags for {number}_::_Edit tags for {number}_" : ["Редагувати мітки для {number}","Редагувати мітки для {number}","Редагувати мітки для {number}","Редагувати мітки для {number}"],
    "_Move {number} thread_::_Move {number} threads_" : ["Перемістити {number} ланцюжок","Перемістити {number} ланцюжки","Перемістити {number} ланцюжків","Перемістити {number} ланцюжків"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Переслати {number} як вкладення","Переслати {number} як вкладення","Переслати {number} як вкладення","Переслати {number} як вкладення"],
    "Report this bug" : "Повідомити про помилку",
    "Event created" : "Подію створено",
    "Could not create event" : "Не вдалося створити подію",
    "All day" : "Весь день",
    "Select calendar" : "Виберіть календар",
    "Description" : "Опис",
    "Create" : "Створити",
    "This event was updated" : "Цю подія було оновлено",
    "{attendeeName} accepted your invitation" : "{attendeeName} прийняв ваше запрошення",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} попередньо прийняв ваше запрошення",
    "{attendeeName} declined your invitation" : "{attendeeName} відхилив ваше запрошення",
    "{attendeeName} reacted to your invitation" : "{attendeeName} відреагував на ваше запрошення",
    "Failed to save your participation status" : "Не вдалося зберегти ваш статус участи",
    "You accepted this invitation" : "Ви прийняли це запрошення",
    "You tentatively accepted this invitation" : "Ви тимчасово прийняли це запрошення",
    "You declined this invitation" : "Ви відхилили це запрошення",
    "You already reacted to this invitation" : "Ви вже відреагували на це запрошення.",
    "You have been invited to an event" : "Вас запросили на подію",
    "This event was cancelled" : "Цей захід було скасовано",
    "Save to" : "Зберегти в",
    "Select" : "Вибрати",
    "Comment" : "Коментар",
    "Accept" : "Прийняти",
    "Decline" : "Відхилити",
    "Tentatively accept" : "Попередньо прийнято",
    "More options" : "Більше варіантів",
    "individual" : "індивідуально",
    "domain" : "домен",
    "Remove" : "Вилучити",
    "email" : "електронна пошта",
    "To archive a message please configure an archive mailbox in account settings" : "Для архівування повідомлення налаштуйте каталог архіву вашої поштової скринькі в налаштуваннях облікового запису",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "У вас відсутній доступ переміщувати це повідомлення до каталогу архіву та/або вилучати з поточного каталогу",
    "Could not open mailbox" : "Неможливо відкрити поштову скриньку",
    "Loading messages …" : "Завантаження повідомлень ...",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Індексування повідомлень. Ця дія може забрати більше часу для поштових скриньок з великим обсягом повідомлень.",
    "Choose target mailbox" : "Виберіть поштову скриньку призначення",
    "No more submailboxes in here" : "Жодних вкладених поштових скриньок більше не знайдено тут",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Повідомлення автоматично будуть позначатися як важливі на основі повідомлень, з якими ви взаємодієте або позначаєте як важливі. Спочатку вам потрібно буде вручну змінювати важливість, щоб навчити систему, але з часом автоматичне визначення важливих повідомлень покращиться.",
    "Important info" : "Важлива інформація",
    "Other" : "Інші",
    "The sender of this message has asked to be notified when you read this message." : "Відправник цього повідомлення попросив його/її повідомити, коли ви прочитаєте це повідомлення.",
    "Notify the sender" : "Повідомити відправника",
    "You sent a read confirmation to the sender of this message." : "Ви надіслали підтвердження про прочитання відправнику цього повідомлення.",
    "Message was snoozed" : "Повідомлення було відкладено",
    "Could not snooze message" : "Неможливо відкласти повідомлення",
    "Message was unsnoozed" : "Повідомлення знову актуалізовано.",
    "Could not unsnooze message" : "Неможливо актуалізувати повідомлення",
    "Forward" : "Переслати",
    "Move message" : "Перемістити повідомлення",
    "Translate" : "Перекласти",
    "Forward message as attachment" : "Надіслати повідомлення вкладенням",
    "View source" : "Джерело",
    "Download thread data for debugging" : "Звантажити дані ланцюжка для зневадження",
    "Message body" : "Текст повідомлення",
    "Unnamed" : "Без назви",
    "Embedded message" : "Вбудоване повідомлення",
    "calendar imported" : "календар імпортовано",
    "Choose a folder to store the attachment in" : "Виберіть каталог для збереження вкладень",
    "Import into calendar" : "Імпортувати до календаря",
    "Download attachment" : "Звантажити вкладення",
    "Save to Files" : "Зберегти до Файлів",
    "View fewer attachments" : "Переглядайте менше вкладень",
    "Choose a folder to store the attachments in" : "Виберіть каталог для збереження вкладень",
    "Save all to Files" : "Зберегти все до Файлів",
    "Download Zip" : "Звантажити архів ZIP",
    "_View {count} more attachment_::_View {count} more attachments_" : ["Переглянути ще {count} вкладень","Переглянути ще {count} вкладень","Переглянути ще {count} вкладень","Переглянути ще {count} вкладень"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Це повідомлення зашифровано за допомогою PGP. Встановіть Mailvelope для розшифрування.",
    "The images have been blocked to protect your privacy." : "Зображення не показуються з міркувань безпеки.",
    "Show images" : "Показати зображення",
    "Show images temporarily" : "Показати зображення цього разу",
    "Always show images from {sender}" : "Завжди показувати зображення від {sender}",
    "Always show images from {domain}" : "Завжди показувати зображення від {domain}",
    "Message frame" : "Область повідомлення",
    "Quoted text" : "Процитований текст",
    "Move" : "Перемістити",
    "Moving" : "Переміщення",
    "Moving thread" : "Переміщення ланцюжка",
    "Moving message" : "Переміщення повідомлення",
    "Loading …" : "Завантаження...",
    "Not supported by the server" : "Не підтримується сервером",
    "{usage} of {limit} used" : "Використано {usage} із {limit}",
    "Remove account" : "Вилучити обліковий запис",
    "Remove {email}" : "Вилучити {email}",
    "Provisioned account is disabled" : "Автоматично налаштований обліковий запис вимкнено",
    "Quota" : "Обмеження",
    "Show only subscribed mailboxes" : "Показувати лише передплачені поштові скриньки",
    "Add mailbox" : "Додати поштову скриньку",
    "Mailbox name" : "Назва поштової скриньки",
    "Saving" : "Збереження",
    "Move up" : "Пересунуту догори",
    "Move down" : "Пересунути вниз",
    "Show all subscribed mailboxes" : "Показати всі поштові скриньки, на які підписано",
    "Show all mailboxes" : "Показати всі поштові скриньки",
    "Collapse mailboxes" : "Згорнути поштові скриньки",
    "_{total} message_::_{total} messages_" : ["{total} повідомлення","{total} повідомлення","{total} повідомлень","{total} повідомлень"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочитано з {total}","{unread} непрочитано з {total}","{unread} непрочитано з {total}","{unread} непрочитано з {total}"],
    "All messages in mailbox will be deleted." : "Усі повідомлення у поштовій скриньці буде вилучено.",
    "Clear mailbox {name}" : "Очистити поштову скриньку {name}",
    "Clear mailbox" : "Очистити поштову скриньку",
    "The mailbox and all messages in it will be deleted." : "Поштову скриньку та всі повідомлення у скриньці буде вилучено.",
    "Delete mailbox" : "Вилучили поштову скриньку",
    "Delete mailbox {name}" : "Вилучити поштову скриньку {name}",
    "An error occurred, unable to rename the mailbox." : "Сталася помилка. Неможливо перейменувати поштову скриньку.",
    "Mark all as read" : "Всі прочитані",
    "Mark all messages of this mailbox as read" : "Позначити всі повідомлення з цієї поштової скриньки як прочитані",
    "Add submailbox" : "Додати вкладену поштову скриньку",
    "Rename" : "Перейменувати",
    "Move mailbox" : "Перемістити поштову скриньку",
    "Clear cache" : "Очистити кеш",
    "Clear locally cached data, in case there are issues with synchronization." : "Очистити локально кешовані дані у разі проблем з синхронізацією.",
    "Subscribed" : "Підписано",
    "Sync in background" : "Синхронізація у фоновому режимі",
    "Outbox" : "Вихідні",
    "New message" : "Нове повідомлення",
    "Edit message" : "Редагувати повідомлення",
    "Draft" : "Чернетка",
    "Reply" : "Відповісти",
    "Message saved" : "Повідомлення збережено",
    "Failed to save message" : "Не вдалося зберегти повідомлення",
    "Failed to save draft" : "Не вдалося зберегти чернетку",
    "attachment" : "вкладення",
    "attached" : "прикріплено",
    "No sent mailbox configured. Please pick one in the account settings." : "Відсутня налаштована скринька відправлених повідомлено. Виберіть скриньку в налаштуваннях облікового запису.",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Ви намагаєтесь надіслати лист занадто багатьом отримувачам, яких зазначили у полі \"Кому\" та/або \"Копія\". Розгляньте можливість використання полі \"Прихована копія\" для приховування адрес отримувачів.",
    "You mentioned an attachment. Did you forget to add it?" : "Ви згадали про вкладення. Чи ви часом не забули його долучити?",
    "Message discarded" : "Відхилено повідомлення",
    "Could not discard message" : "Не вдалося відхилити повідомлення",
    "Maximize composer" : "Редактор на весь екран",
    "Minimize composer" : "Згорнути редактор",
    "Error sending your message" : "Помилка під час надсилання повідомлення",
    "Retry" : "Ще раз",
    "Warning sending your message" : "Застереження під час надсилання вашого повідомлення",
    "Send anyway" : "Надіслати все одно",
    "Autoresponder off" : "Автовідповідач вимкнено",
    "Autoresponder on" : "Автовідповідач увімкнено",
    "Autoresponder follows system settings" : "Автовідповідач налаштовано згідно з налаштуваннями системи",
    "The autoresponder follows your personal absence period settings." : "Автовідповідач налаштовано згідно з вашими налаштуваннями часу вашої відсутності.",
    "Edit absence settings" : "Редагувати налаштування відсутності",
    "First day" : "Перший день",
    "Last day (optional)" : "Останній день (необов'язково)",
    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} буде замінено на тему повідомлення, на яке ви відповідаєте",
    "Message" : "Повідомлення",
    "Oh Snap!" : "От халепа!",
    "Save autoresponder" : "Зберегти налаштування автовідповідача",
    "Could not open outbox" : "Не вдалося відкрити вихідну скриньку",
    "Pending or not sent messages will show up here" : "Тут відображатимуться незавершені або не надіслані повідомлення",
    "Could not copy to \"Sent\" mailbox" : "Не вдалося скопіюати до \"Надіслані\"",
    "Message could not be sent" : "Повідомлення неможливо надіслати",
    "Message deleted" : "Повідомлення вилучено",
    "Copy to \"Sent\" Mailbox" : "Копіювати до \"Надіслані\"",
    "Copy to Sent Mailbox" : "Копіювати до \"Надіслані\"",
    "Copied email address to clipboard" : "Адресу електронної пошти скопійовано до буферу обміну",
    "Could not copy email address to clipboard" : "Не вдалося скопіювати адресу електронної пошти до буфера обміну",
    "Contacts with this address" : "Контакти з такою адресою",
    "Add to Contact" : "Додати до контакту",
    "New Contact" : "Новий контакт",
    "Copy to clipboard" : "Копіювати до буферу обміну ",
    "Contact name …" : "Ім'я контакту ...",
    "Add" : "Додати",
    "Show less" : "Показувати менше",
    "Show more" : "Показати більше",
    "Clear" : "Очистити",
    "Search in mailbox" : "Шукати в поштовій скринці",
    "Close" : "Закрити",
    "Search parameters" : "Параметри пошуку",
    "Search subject" : "Шукати в темі",
    "Body" : "Тіло",
    "Search body" : "Шукати в тілі повідомлень",
    "Date" : "Дата",
    "Pick a start date" : "Виберіть дату початку",
    "Pick an end date" : "Виберіть дату завершення",
    "Select senders" : "Виберіть відправників",
    "Select recipients" : "Виберіть отримувачів",
    "Select CC recipients" : "Виберіть отримувачів в копії",
    "Select BCC recipients" : "Виберіть отримувачів прихованої копії",
    "Tags" : "Мітки",
    "Select tags" : "Виберіть мітки",
    "Marked as" : "Позначено як",
    "Has attachments" : "Має вкладення",
    "Has attachment" : "Має вкладення",
    "Last 7 days" : "За останні 7 днів",
    "From me" : "Від мене",
    "Enable mail body search" : "Увімкнути пошук в тілі повідомлень",
    "Sieve Port" : "Порт Sieve",
    "Custom" : "Custom",
    "Sieve User" : "Користувач Sieve",
    "Sieve Password" : "Пароль Sieve",
    "Save sieve settings" : "Зберегти налаштування Sieve",
    "The syntax seems to be incorrect:" : "Здається, синтаксис неправильний:",
    "Save sieve script" : "Зберегти скрипт Sieve",
    "Signature …" : "Підпис...",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Ваш підпис перевищує 2 МБ. Це може вплинути на продуктивність вашого редактора.",
    "Save signature" : "Зберегти підпис",
    "Place signature above quoted text" : "Розмістити підпис над цитованим текстом",
    "An error occurred, unable to rename the tag." : "Сталася помилка. Неможливо перейменувати мітку.",
    "Edit name or color" : "Редагувати назву або колір",
    "Saving new tag name …" : "Збереження нової назви мітки ...",
    "Delete tag" : "Вилучити мітку",
    "Set tag" : "Встановити мітку",
    "Unset tag" : "Прибрати встановлення мітки",
    "Tag name is a hidden system tag" : "Назва мітки - це прихована системна мітка",
    "Tag already exists" : "Мітка вже існує",
    "Tag name cannot be empty" : "Назва мітки не може бути порожньою",
    "An error occurred, unable to create the tag." : "Сталася помилка. Неможливо створити мітку.",
    "Add default tags" : "Додати типові мітки",
    "Add tag" : "Додати мітку",
    "Saving tag …" : "Збереження мітки ...",
    "Task created" : "Завдання створено",
    "Could not create task" : "Не вдалося створити завдання",
    "No calendars with task list support" : "Відсутні календарі з підтримкою списку завдань",
    "Could not load your message thread" : "Не вдалось завантажити ваш ланцюжок повідомлень",
    "The thread doesn't exist or has been deleted" : "Ланцюжок відсутній або його було вилучено",
    "Loading thread" : "Завантаження ланцюжка",
    "Not found" : "Не знайдено",
    "Encrypted & verified " : "Зашифровано та перевірено",
    "Signature verified" : "Підпис перевірено",
    "Signature unverified " : "Підпис не перевірено",
    "This message was encrypted by the sender before it was sent." : "Це повідомлення було зашифровано відправником перед тим, як його надіслати.",
    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Це повідомлення містить перевірений цифровий підпис S/MIME. Повідомлення не змінювалося з моменту його надсилання.",
    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Це повідомлення містить неперевірений цифровий підпис S/MIME. Повідомлення могло бути змінено після надсилання або сертифікат підписувача недовірений.",
    "Reply all" : "Відповісти всім",
    "Unsubscribe request sent" : "Надіслано запит щодо відписування",
    "Could not unsubscribe from mailing list" : "Не вдалося відписатися від списку розсилки",
    "Unsubscribe" : "Відписатися",
    "Reply to sender only" : "Відповісти лише відправникові",
    "Mark as unfavorite" : "Прибрати зірочку",
    "Mark as favorite" : "Позначити зірочкою",
    "Mark as unread" : "Позначити не прочитаним",
    "Mark as read" : "Позначити прочитаним",
    "Message source" : "Джерело повідомлення",
    "Unsubscribe via link" : "Відписатися через посилання",
    "Send unsubscribe email" : "Надіслати електронний лист щодо відписування",
    "Unsubscribe via email" : "Відпусатися через ел.пошту",
    "{name} Assistant" : "Асистент {name}",
    "Go to latest message" : "Перейти до останнього повідомлення",
    "Go to newest message" : "Перейти до найновішого повідомлення",
    "Translate from" : "Перекласти з",
    "Translate to" : "Перекласти",
    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Вимкніть зберігання кошика, для цього залиште поле порожнім або встановіть його значення у 0. Це буде застосовано лише до листів, які було вилучено після увімкнення зберігання кошика.",
    "Could not remove trusted sender {sender}" : "Не вдалося вилучити довіреного відправника {sender}",
    "No senders are trusted at the moment." : "Наразі відсутні довірені відправники.",
    "Untitled event" : "Подія без назви",
    "(organizer)" : "(організатор)",
    "Import into {calendar}" : "Імпортувати до {calendar}",
    "Event imported into {calendar}" : "Подію імпортовано до {calendar}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Рейс {flightNr} з {depAirport} до {arrAirport}",
    "Airplane" : "Літак",
    "Reservation {id}" : "Бронювання {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} від {depStation} до {arrStation}",
    "Train from {depStation} to {arrStation}" : "Потяг з {depStation} до {arrStation}",
    "Train" : "Потяг",
    "Delete filter" : "Вилучити фільтр",
    "Operator" : "Оператор",
    "contains" : "містить",
    "matches" : "містить",
    "Priority" : "Пріоритет",
    "Mail app" : "Електронна пошта",
    "The mail app allows users to read mails on their IMAP accounts." : "Застосунок пошти дозволяє користувачам переглядати з їхніх облікових записів IMAP.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Тут ви можете знайти налаштування для всього примірника хмари. Налаштування користувача розташовані у застосунку (див. у лівому нижньому куті).",
    "Account provisioning" : "Автоматичне налаштування облікового запису",
    "A provisioning configuration will provision all accounts with a matching email address." : "За допомогою автоматичного налаштування буде налаштовано всі електронні скриньки з відповідними ел. адресами.",
    "Add new config" : "Додати нову конфігурацію",
    "Allow additional Mail accounts from User Settings" : "Дозволити додаткові налаштування поштових облікових записів у налаштуваннях користувача",
    "Gmail integration" : "Інтеграція з Gmail",
    "Microsoft integration" : "Інтеграція з Microsoft",
    "Anti Spam" : "Антиспам",
    "Reset" : "Скидання",
    "Google integration configured" : "Інтеграцію з Google налаштовано",
    "Client ID" : "Ідентифікатор клієнта",
    "Client secret" : "Ключ клієнта",
    "Microsoft integration unlinked" : "Інтеграцію з Microsoft відключено",
    "Email: {email}" : "Ел.пошта: {email}",
    "Email address template" : "Шаблон адреси електронної пошти",
    "IMAP" : "IMAP",
    "User" : "Користувач",
    "Host" : "Хост",
    "Port" : "Порт",
    "SMTP" : "SMTP",
    "Certificate imported successfully" : "Сертифікат успішно імпортовано",
    "E-mail address" : "Електронна адреса",
    "Valid until" : "Дійсно до",
    "Delete certificate" : "Видалити сертифікат",
    "Certificate" : "Сертифікат",
    "Private key (optional)" : "Приватний ключ (необов'язково)",
    "Submit" : "Гаразд",
    "Account connected" : "Обліковий запис під’єднано",
    "You can close this window" : "Ви можете закрити це вікно",
    "Connect your mail account" : "Під'єднати вашу поштову скриньку",
    "To add a mail account, please contact your administrator." : "Щоби додати поштову скриньку, будь ласка, зверніться до адміністратора",
    "All" : "Всі",
    "Drafts" : "Чернетки",
    "Favorites" : "Із зірочкою",
    "Priority inbox" : "Важливі",
    "All inboxes" : "Всі вхідні",
    "Inbox" : "Вхідні",
    "Junk" : "Спам",
    "Sent" : "Надіслані",
    "Trash" : "Кошик",
    "Error while sharing file" : "Помилка під час надання спільного доступу до файлу",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n нове повідомлення\nвід {from}","%n нові повідомлення\nвід {from}","%n нових повідомлень\nвід {from}","%n нових повідомлень\nвід {from}"],
    "Nextcloud Mail" : "Пошта Nextcloud",
    "Discard changes" : "Відкинути зміни",
    "Discard unsaved changes" : "Відкинути незбережені зміни",
    "Message sent" : "Повідомлення відправлено",
    "Could not load {tag}{name}{endtag}" : "Не вдалося завантажити {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Виникла проблема із завантаженням {tag}{name}{endtag}",
    "Could not load your message" : "Неможливо завантажити повідомлення",
    "Could not load the desired message" : "Неможливо завантажити обране повідомлення",
    "Could not load the message" : "Неможливо завантажити повідомлення",
    "Error loading message" : "Помилка завантаження повідомлення.",
    "Forwarding to %s" : "Переслати до %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Натисніть тут, якщо вас не буде автоматично перенаправлено протягом наступних кількох секунд.",
    "Redirect" : "Перенаправлення",
    "The link leads to %s" : "Посилання веде до %s",
    "Continue to %s" : "Перейти до %s",
    "Actions" : "Дії",
    "New action" : "Нова дія"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
